# -*- coding: utf-8 -*-
"""
Created on Sat Jun  4 04:14:19 2017

@author: Young Ju Kim
"""


import zipfile
import io
import os
from os.path import dirname, abspath


class TaxonomySerializer:
    
    def __init__(self, locale):
        
        ifrsLabelFullStr = ""
        filePath = dirname(abspath(__file__))
        zipDirPath = filePath + r'/{lang_locale}/zip/'.format(lang_locale=locale)
        zipList = os.listdir(zipDirPath)
        
        for file in zipList:
            
            zipFilePath = zipDirPath + file
            with zipfile.ZipFile(zipFilePath, 'r') as archive:

                fileList = archive.namelist()
                ifrsLableFileList = [item for item in fileList if ('label' in item) &
                                                      ('lab_' in item) &
                                                      (item.endswith(r'.xml'))]
                
                for name in ifrsLableFileList:
                    
                    ifrsLabelFile = archive.open(ifrsLableFileName)
                    ifrsLabelStr = io.TextIOWrapper(ifrsLabelFile).read()
                    ifrsLabelFullStr += ifrsLabelStr
                
        self.parsed = ifrsLabelFullStr
    
    
    def dump(self):
        
        with open('label.dump', 'w') as new:
            new.write(ifrsLabelFullStr)
        return ifrsLabelFullStr








from setuptools import setup, find_packages


long_desc = """
This is made for some specific environment.
This contains ...

IFRS Taxonomy : http://www.ifrs.org/Use-around-the-world/IFRS-translations/Pages/IFRS-Taxonomy-in-Korean.aspx

"""

setup(name='ifrs',
        version='0.0.0.1c',
        description='useful tools for Korean Financial Statement disclosured on https://dart.fss.or.kr',
        long_description=long_desc,
        url='http://github.com/pydemia/ifrs',
        author='Young-Ju Kim',
        author_email='pydemia@gmail.com',
        license='MIT License',
        classifiers=[
                # How Mature: 3 - Alpha, 4 - Beta, 5 - Production/Stable
                'Development Status :: 3 - Alpha',
                'Programming Language :: Python :: 3.5'
                ],
        packages=find_packages(exclude=['contrib', 'docs', 'tests']),
        install_requires=['python-xbrl'],
        zip_safe=False)
